package cn.minestar.agriculture.service;

import java.util.List;

import cn.minestar.agriculture.entity.WxMiniInfo;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author www.minestar.cn/
 * @date 2021-08-10
 */
public interface IWxMiniInfoService 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public WxMiniInfo selectWxMiniInfoById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param wxMiniInfo 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<WxMiniInfo> selectWxMiniInfoList(WxMiniInfo wxMiniInfo);

    /**
     * 新增【请填写功能名称】
     * 
     * @param wxMiniInfo 【请填写功能名称】
     * @return 结果
     */
    public int insertWxMiniInfo(WxMiniInfo wxMiniInfo);

    /**
     * 修改【请填写功能名称】
     * 
     * @param wxMiniInfo 【请填写功能名称】
     * @return 结果
     */
    public int updateWxMiniInfo(WxMiniInfo wxMiniInfo);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    public int deleteWxMiniInfoByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteWxMiniInfoById(Long id);
}
